@@ -73,39 +73,47 @@
 #  endif
 #endif
 
-struct uu1 {
-  U32 time_low;
-  U16 time_mid;
-  U16 time_high_and_version;
-  U16 clock_seq_and_variant;
-  U8  node[6];
+typedef union {
+  struct {
+    U32 time_low;
+    U16 time_mid;
+    U16 time_high_and_version;
+    U16 clock_seq_and_variant;
+    U8  node[6];
+  } members;
   U64 __align;
-};
+} struct_uu1_t;
 
-struct uu4 {
-  U32 rand_a;
-  U32 rand_b_and_version;
-  U32 rand_c_and_variant;
-  U32 rand_d;
+typedef union {
+  struct {
+    U32 rand_a;
+    U32 rand_b_and_version;
+    U32 rand_c_and_variant;
+    U32 rand_d;
+  } members;
   U64 __align;
-};
+} struct_uu4_t;
 
-struct uu6 {
-  U32 time_high;
-  U16 time_mid;
-  U16 time_low_and_version;
-  U16 clock_seq_and_variant;
-  U8  node[6];
+typedef union {
+  struct {
+    U32 time_high;
+    U16 time_mid;
+    U16 time_low_and_version;
+    U16 clock_seq_and_variant;
+    U8  node[6];
+  } members;
   U64 __align;
-};
+} struct_uu6_t;
 
-struct uu7 {
-  U32 time_high;
-  U16 time_low;
-  U16 rand_a_and_version;
-  U64 rand_b_and_variant;
+typedef union {
+  struct {
+    U32 time_high;
+    U16 time_low;
+    U16 rand_a_and_version;
+    U64 rand_b_and_variant;
+  } members;
   U64 __align;
-};
+} struct_uu7_t;
 
 typedef unsigned char UCHAR;
 
