@@ -3,7 +3,7 @@
 
 #include "ulib/UUID.h"
 
-IV uu_parse(const char *in, struct uu1 *out);
+IV uu_parse(const char *in, struct_uu1_t *out);
 
 #endif
 /* ex:set ts=2 sw=2 itab=spaces: */
